Downstream runtimes must set the current tenant telemetry context via
greentic_types::telemetry::set_current_tenant_ctx before executing flows
(for example, prior to FlowEngine::run in the host runner).
Re-exports
pub use flow_bundle::ComponentPin;pub use flow_bundle::FlowBundle;pub use flow_bundle::NodeRef;pub use flow_bundle::blake3_hex;pub use flow_bundle::canonicalize_json;pub use flow_bundle::extract_component_pins;pub use flow_bundle::load_and_validate_bundle;pub use flow_bundle::load_and_validate_bundle_with_flow;pub use json_output::JsonDiagnostic;pub use json_output::LintJsonOutput;pub use json_output::lint_to_stdout_json;pub use splice::NEXT_NODE_PLACEHOLDER;pub use splice::splice_node_after;
Modules
- add_
step - answers
- cache
- component_
catalog - component_
schema - component_
setup - config_
flow - contracts
- error
- flow_
bundle - flow_ir
- flow_
meta - i18n
- info
- ir
- json_
output - lint
- loader
- model
- path_
safety - qa_
runner - questions
- questions_
schema - registry
- resolve
- resolve_
summary - schema_
mode - schema_
validate - splice
- template
- util
- wizard
- wizard_
ops - wizard_
state
Constants
- SLOT_
SCHEMA_ METADATA_ KEY - Metadata key under which compiled flows expose their flow-level slot schema.
Functions
- compile_
flow - Compile a validated
FlowDocinto the canonicalFlowmodel. - compile_
ygtc_ file - Compile a YGTC file into
Flow. - compile_
ygtc_ str - Compile YGTC YAML text into
Flow. - map_
flow_ type - Map a YAML flow type string to
FlowKind.