Module loader

Module loader 

Functions

ensure_config_schema_path
Ensure a temporary copy of the embedded flow schema exists and return its path.
load_ygtc_from_path
Load YGTC YAML from a file path using the embedded schema.
load_ygtc_from_str
Load YGTC YAML from a string using the embedded schema.
load_ygtc_from_str_with_schema
Load YGTC YAML from a string using a schema file on disk.
load_ygtc_from_str_with_source